Crate reifydb_type

Crate reifydb_type 

Modules

error
fragment
params
storage
util
value

Macros

cow_vec
err
Macro to create an Err(Error()) from a diagnostic function call
error
Macro to create an Error from a diagnostic function call
params
return_error
Macro to return an error from a diagnostic function call

Type Aliases

Result
Result type alias for this crate